pub struct ParentForm {Show 29 fields
pub lives: bool,
pub title: String,
pub gender: String,
pub relationship: String,
pub family_name: String,
pub given_name: String,
pub birth_date: Option<NaiveDateTime>,
pub country_of_birth: String,
pub aboriginality: AboriginalityType,
pub occupation_group: OccupationType,
pub occupation: Option<String>,
pub schooling_type: SchoolingType,
pub qualification: QualificationType,
pub other_languages: bool,
pub other_main_lang: Option<String>,
pub other_langs: Option<String>,
pub interviews: bool,
pub address: String,
pub address_to_enrol: bool,
pub correspondence_address: Option<String>,
pub name: String,
pub mobile_phone: Option<String>,
pub comments_mobile: Option<String>,
pub home_phone: Option<String>,
pub comments_home: Option<String>,
pub work_phone: Option<String>,
pub comments_work: Option<String>,
pub email: String,
pub key: i32,
}Fields
lives: booltitle: Stringgender: Stringrelationship: Stringfamily_name: Stringgiven_name: Stringbirth_date: Option<NaiveDateTime>country_of_birth: Stringaboriginality: AboriginalityTypeoccupation_group: OccupationTypeoccupation: Option<String>schooling_type: SchoolingTypequalification: QualificationTypeother_languages: boolother_main_lang: Option<String>other_langs: Option<String>interviews: booladdress: Stringaddress_to_enrol: boolcorrespondence_address: Option<String>name: Stringmobile_phone: Option<String>comments_mobile: Option<String>home_phone: Option<String>comments_home: Option<String>work_phone: Option<String>comments_work: Option<String>email: Stringkey: i32Trait Implementations
Sourceimpl Clone for ParentForm
impl Clone for ParentForm
Sourcefn clone(&self) -> ParentForm
fn clone(&self) -> ParentForm
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ParentForm
impl Debug for ParentForm
Sourceimpl<'de> Deserialize<'de> for ParentForm
impl<'de> Deserialize<'de> for ParentForm
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl<'a> FromSql<'a> for ParentForm
impl<'a> FromSql<'a> for ParentForm
Sourcefn from_sql(
_type: &Type,
buf: &'a [u8],
) -> Result<ParentForm, Box<dyn Error + Sync + Send>>
fn from_sql( _type: &Type, buf: &'a [u8], ) -> Result<ParentForm, Box<dyn Error + Sync + Send>>
Creates a new value of this type from a buffer of data of the specified
Postgres
Type in its binary format. Read moreSourcefn accepts(type_: &Type) -> bool
fn accepts(type_: &Type) -> bool
Determines if a value of this type can be created from the specified
Postgres
Type.Sourceimpl PartialEq for ParentForm
impl PartialEq for ParentForm
Sourceimpl Serialize for ParentForm
impl Serialize for ParentForm
Sourceimpl ToSql for ParentForm
impl ToSql for ParentForm
Sourcefn to_sql(
&self,
_type: &Type,
buf: &mut BytesMut,
) -> Result<IsNull, Box<dyn Error + Sync + Send>>
fn to_sql( &self, _type: &Type, buf: &mut BytesMut, ) -> Result<IsNull, Box<dyn Error + Sync + Send>>
Converts the value of
self into the binary format of the specified
Postgres Type, appending it to out. Read moreSourcefn accepts(type_: &Type) -> bool
fn accepts(type_: &Type) -> bool
Determines if a value of this type can be converted to the specified
Postgres
Type.Sourcefn to_sql_checked(
&self,
ty: &Type,
out: &mut BytesMut,
) -> Result<IsNull, Box<dyn Error + Sync + Send>>
fn to_sql_checked( &self, ty: &Type, out: &mut BytesMut, ) -> Result<IsNull, Box<dyn Error + Sync + Send>>
An adaptor method used internally by Rust-Postgres. Read more
Sourcefn encode_format(&self, _ty: &Type) -> Format
fn encode_format(&self, _ty: &Type) -> Format
Specify the encode format
impl StructuralPartialEq for ParentForm